# Examples

## Demos
- [Demo](https://www.cvxgrp.org/cvxrisk/marimo/demo.html)
- [Factor Model](https://www.cvxgrp.org/cvxrisk/marimo/factormodel.html)
- [Large Dimensions](https://www.cvxgrp.org/cvxrisk/marimo/large.html)
- [Sample Covariance](https://www.cvxgrp.org/cvxrisk/marimo/sample.html)
